bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.get_shape
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGamma.get_shape